@@ -6,11 +6,11 @@ if sys.version_info > (3,0):
 #
 # These packages contain plugins that need to be loaded
 #
-packages = ['coopr.opt', 'coopr.pyomo', 'coopr.os', 'coopr.pysp', 'coopr.neos', 'coopr.openopt', 'coopr.solvers', 'coopr.gdp', 'coopr.mpec', 'coopr.dae', 'coopr.bilevel']
+packages = ['coopr.opt', 'coopr.pyomo', 'coopr.os', 'coopr.pysp', 'coopr.neos', 'coopr.openopt', 'coopr.solvers', 'coopr.gdp', 'coopr.mpec', 'coopr.dae', 'coopr.bilevel', 'coopr.neos', 'coopr.bilevel', 'coopr.mpec']
 # 
 # These packages are under development, or they may be omitted in a Coopr installation
 #
-optional_packages = set(['coopr.neos', 'coopr.bilevel', 'coopr.mpec'])
+optional_packages = set([])
 
 
 def do_import(pname):
@@ -34,7 +34,10 @@ def import_packages():
             except ImportError:
                 pass
         else:
-            do_import(pname)
+            try:
+                do_import(pname)
+            except ImportError:
+                raise ImportError("Failed to import %s" % pname)
             imported = True
         if imported:
             pkg = sys.modules[pname]
